@@ -54,7 +54,7 @@ class DataCenter(object):
     """
     def __init__(self, location=None, key_id=None, secret='~/.ssh/id_rsa', 
                 headers=None, login=None, config=None, known_locations=None,
-                allow_agent=True):
+                allow_agent=False):
         """
         A :py:class:`smartdc.datacenter.DataCenter` object may be instantiated 
         without any parameters, but practically speaking, the `key_id` and 
@@ -82,6 +82,9 @@ class DataCenter(object):
         :param known_locations: keys-to-URLs mapping used by `location` 
         :type known_locations: :py:class:`dict`
         
+        :param allow_agent: whether or not to try ssh-agent
+        :type allow_agent: :py:class:`bool`
+        
         The `location` is notionally a hostname, but it may be 
         expressed as an FQDN, one of the keys to the `known_locations` dict, 
         or, as a fallback, a bare hostname as prefix to the API_HOST_SUFFIX.
@@ -170,7 +173,7 @@ class DataCenter(object):
         else:
             return 'https://' + self.location + API_HOST_SUFFIX
     
-    def authenticate(self, key_id=None, secret=None, allow_agent=True):
+    def authenticate(self, key_id=None, secret=None, allow_agent=False):
         """
         :param key_id: SmartDC identifier for the ssh key
         :type key_id: :py:class:`basestring`
@@ -178,6 +181,9 @@ class DataCenter(object):
         :param secret: path to private rsa key
         :type secret: :py:class:`basestring`
         
+        :param allow_agent: whether or not to try ssh-agent
+        :type allow_agent: :py:class:`bool`
+        
         If no `key_id` or `secret` were entered on initialization, or there is
         a need to change the existing authentication credentials, one may 
         authenticate with a `key_id` and `secret`.
@@ -207,15 +213,17 @@ class DataCenter(object):
         request_headers.update(self.default_headers)
         if headers:
             request_headers.update(headers)
+        jdata = None
         if data:
-            data = json.dumps(data)
-            kwargs['data'] = data
+            jdata = json.dumps(data)
         resp = requests.request(method, full_path, auth=self.auth, 
-            headers=request_headers, config=self.config, **kwargs)
+            headers=request_headers, config=self.config, data=jdata,
+            **kwargs)
         if (resp.status_code == 401 and self.auth and 
                 self.auth.signer._agent_key):
             self.auth.signer.swap_keys()
-            return self.request(method, path, headers=headers, **kwargs)
+            return self.request(method, path, headers=headers, data=data,
+                **kwargs)
         if 400 <= resp.status_code < 499:
             if resp.content:
                 print >> sys.stderr, resp.content
